@@ -62,13 +62,7 @@ def create_all_metadata(
 
 
 def create_metadata_folder(
-    connection,
-    save_folder,
-    title,
-    description,
-    schema,
-    source_bucket,
-    source_folder,
+    connection, save_folder, title, description, schema, source_bucket, source_folder,
 ):
     """
     Creates a folder of metadata readable by etl_manager's read_database_folder.
@@ -129,11 +123,7 @@ def create_metadata_folder(
 
 
 def create_json_for_database(
-    description: str,
-    name: str,
-    bucket: str,
-    base_folder: str,
-    location="./meta_data",
+    description: str, name: str, bucket: str, base_folder: str, location="./meta_data",
 ):
     """Creates a database.json file suitable for reading with read_database_folder()
 
@@ -294,7 +284,7 @@ def get_table_meta(
         This data is automatically added by AWS DMS ongoing replication tasks.
 
     include_timestamp_column (boolean):
-        If True, adds a column called 'EXTRACTION_TIMESTAMP'
+        If True, adds a column called 'extraction_timestamp'
         This data is added by AWS DMS, when configured as an extra connection attribute.
 
     include_derived_columns (boolean):
@@ -340,7 +330,7 @@ def get_table_meta(
     if include_timestamp_column:
         columns.append(
             {
-                "name": "EXTRACTION_TIMESTAMP",
+                "name": "extraction_timestamp",
                 "type": "character",
                 "description": "DMS extraction timestamp",
                 "nullable": False,
@@ -362,12 +352,17 @@ def get_table_meta(
     # null_ok isn't accurate in Delius, so nullable uses an external dict
     for col in cursor.description:
         if col[1].name not in skip:
+            if col[1].name == "DB_TYPE_NUMBER":
+                if col[4] == 0 and col[5] == -127:
+                    column_type = "int"
+                else:
+                    column_type = f"decimal({col[4]},{col[5]})"
+            else:
+                column_type = type_lookup[col[1].name]
             columns.append(
                 {
                     "name": col[0].lower(),
-                    "type": f"decimal({col[4]},{col[5]})"
-                    if col[1].name == "DB_TYPE_NUMBER"
-                    else type_lookup[col[1].name],
+                    "type": column_type,
                     "description": "",
                     "nullable": bool(col[0].lower() not in not_nullable),
                 }
